package cd.casic.module.process.process.setting.impl;

import cd.casic.ci.commons.bean.process.setting.AuthHost;
import cd.casic.ci.commons.bean.process.setting.AuthHostQuery;
import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.framework.mybatis.core.query.LambdaQueryWrapperX;
import cd.casic.framework.security.core.util.SecurityFrameworkUtils;
import cd.casic.module.process.convert.setting.AuthHostConvert;
import cd.casic.module.process.process.setting.AuthHostService;
import cd.casic.module.process.process.setting.dao.AuthHostDao;
import cd.casic.module.process.process.setting.dataobject.AuthHostDo;
import cn.hutool.core.collection.CollectionUtil;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;
import java.util.Objects;

@Service
public class AuthHostServiceImpl implements AuthHostService {

    @Resource
    AuthHostDao authHostDao;

    /**
     * 创建流水线授权
     *
     * @param authHost 流水线授权
     * @return 流水线授权id
     */
    @Override
    public int createAuthHost(AuthHost authHost) {
        AuthHostDo authHostDo = AuthHostConvert.INSTANCE.convertDo(authHost);
        authHostDo.setUserId(SecurityFrameworkUtils.getLoginUserId());
        return authHostDao.insert(authHostDo);
    }

    /**
     * 删除流水线授权
     *
     * @param authHostId 流水线授权id
     */
    @Override
    public void deleteAuthHost(String authHostId) {
        authHostDao.deleteById(authHostId);
    }

    /**
     * 更新授权信息
     *
     * @param authHost 信息
     */
    @Override
    public void updateAuthHost(AuthHost authHost) {
        int authPublic = authHost.getAuthPublic();
        String authId = authHost.getHostId();
        AuthHost oneAuth = findOneAuthHost(authId);
        int hostType = oneAuth.getAuthPublic();
        if (authPublic == 1 && hostType == 2) {
            authHost.setPrivateKey("");
        }
        if (authPublic == 2 && hostType == 1) {
            authHost.setUsername("");
            authHost.setPassword("");
        }
        AuthHostDo authHostDo = AuthHostConvert.INSTANCE.convertDo(authHost);
        authHostDao.updateById(authHostDo);
    }

    /**
     * 查询授权信息
     *
     * @param authHostId id
     * @return 信息集合
     */
    @Override
    public AuthHost findOneAuthHost(String authHostId) {
        AuthHostDo authHostDo = authHostDao.selectById(authHostId);
        return AuthHostConvert.INSTANCE.convert(authHostDo);
    }

    /**
     * 查询所有流水线授权
     *
     * @return 流水线授权列表
     */
    @Override
    public List<AuthHost> findAllAuthHost() {
        List<AuthHostDo> authHostDos = authHostDao.selectList();
        if (Objects.isNull(authHostDos)) {
            return Collections.emptyList();
        }
        return AuthHostConvert.INSTANCE.convertList(authHostDos);
    }

    @Override
    public List<AuthHost> findAllAuthHostList(List<String> idList) {
        List<AuthHostDo> authHostDos = authHostDao.selectByIds(idList);
        return AuthHostConvert.INSTANCE.convertList(authHostDos);
    }


    @Override
    public List<AuthHost> findAuthHostList(AuthHostQuery hostQuery) {
        PageResult<AuthHostDo> authHostDoPageResult = authHostDao.selectPage(hostQuery.getPageParam(), new LambdaQueryWrapperX<AuthHostDo>().eq(AuthHostDo::getUserId, hostQuery.getUserId()));
        if (CollectionUtil.isEmpty(authHostDoPageResult.getList())) {
            return Collections.emptyList();
        }
        return AuthHostConvert.INSTANCE.convertList(authHostDoPageResult.getList());
    }


    @Override
    public PageResult<AuthHost> findAuthHostPage(AuthHostQuery hostQuery) {
        PageResult<AuthHostDo> authHostDoPageResult = authHostDao.selectPage(hostQuery.getPageParam(),
                new LambdaQueryWrapperX<AuthHostDo>().eq(AuthHostDo::getUserId, hostQuery.getUserId()));
        List<AuthHostDo> dataList = authHostDoPageResult.getList();
        if (Objects.isNull(dataList) || dataList.isEmpty()) {
            return PageResult.empty();
        }
        AuthHostConvert.INSTANCE.convertList(dataList);
        return new PageResult<>(AuthHostConvert.INSTANCE.convertList(dataList), authHostDoPageResult.getTotal());
    }


    @Override
    public Long findHostNumber() {
        return authHostDao.selectCount();
    }

}
