package cd.casic.module.process.support.postprocess.controller;

import cd.casic.ci.commons.bean.engine.postprocess.Postprocess;
import cd.casic.ci.commons.bean.utils.Result;
import cd.casic.module.process.support.postprocess.service.PostprocessService;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotNull;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @ClassName PostprocessController
 * @Author hopeli
 * @Date 2025/4/28 10:43
 * @Version 1.0
 */
@RestController
@RequestMapping("/postprocess")
public class PostprocessController {

    @Resource
    PostprocessService postServer;


    /**
     * 创建流水线后置配置
     * @param postprocess
     * @return
     */
    @RequestMapping(path="/createPost",method = RequestMethod.POST)
    public Result<String> createPost(@RequestBody @NotNull @Valid Postprocess postprocess){
        String postId = postServer.createPostTask(postprocess);
        return Result.ok(postId);
    }

    /**
     * 更新流水线后置配置
     * @param postprocess
     * @return
     */
    @RequestMapping(path="/updatePost",method = RequestMethod.POST)
    public Result<Void> updatePost(@RequestBody @NotNull @Valid Postprocess postprocess){
        postServer.updatePostTask(postprocess);
        return Result.ok();
    }


    /**
     * 查询流水线后置配置信息
     * @param pipelineId
     * @return
     */
    @RequestMapping(path="/findPipelinePost",method = RequestMethod.POST)
    public Result<List<Postprocess>> findAllPipelinePostTask(@NotNull String pipelineId) {
        List<Postprocess> list = postServer.findAllPipelinePostTask(pipelineId);
        return Result.ok(list);
    }


    /**
     * 查询流水线任务后置配置信息
     * @param taskId
     * @return
     */
    @RequestMapping(path="/findTaskPost",method = RequestMethod.POST)
    public Result< List<Postprocess>> findAllTaskPostTask(@NotNull String taskId) {
        List<Postprocess> list = postServer.findAllTaskPostTask(taskId);
        return Result.ok(list);
    }


    /**
     * 删除流水线任务后置配置信息
     * @param postId
     * @return
     */
    @RequestMapping(path="/deletePost",method = RequestMethod.POST)
    public Result<Void> deletePost(@NotNull String postId) {
        postServer.deletePostTask(postId);
        return Result.ok();
    }


    /**
     * 查询后置配置信息
     * @param postId
     * @return
     */
    @RequestMapping(path="/findOnePost",method = RequestMethod.POST)
    public Result<Postprocess> findOnePostOrTask(@NotNull String postId) {
        Postprocess postOrTask = postServer.findOnePostOrTask(postId);
        return Result.ok(postOrTask);
    }
}
