package cd.casic.module.process.task.build.service.impl;


/**
 * @ClassName TaskArtifactXpackServiceImpl
 * @Author hopeli
 * @Date 2025/5/2 19:40
 * @Version 1.0
 */

import cd.casic.ci.commons.annotation.rpc.Exporter;
import cd.casic.module.process.support.util.util.PipelineFinal;
import cd.casic.module.process.task.build.dao.TaskBuildDao;
import cd.casic.module.process.task.build.dataobject.TaskBuildDo;
import cd.casic.module.process.task.build.model.TaskBuild;
import cd.casic.module.process.task.build.service.TaskBuildService;
import cd.casic.module.process.toolkit.beans.BeanMapper;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;


@Service
@Exporter
public class TaskBuildServiceImpl implements TaskBuildService {

    @Resource
    TaskBuildDao taskBuildDao;

    //创建
    @Override
    public String createBuild(TaskBuild taskBuild) {
        return taskBuildDao.createBuild(BeanMapper.map(taskBuild, TaskBuildDo.class));
    }

    @Override
    public Boolean buildValid(String taskType,TaskBuild build){
        if (taskType.equals(PipelineFinal.TASK_BUILD_DOCKER)){
            return !StringUtils.isEmpty(build.getDockerFile());
        }
        return true;
    }

    /**
     * 根据配置id查询任务
     * @param authId 配置id
     * @return 任务
     */
    @Override
    public TaskBuild findBuildByAuth(String authId){

        TaskBuild build = findOneBuild(authId);
        if (Objects.isNull(build.getDockerVersion())){
            build.setDockerVersion("latest");
        }
        return build;
    }

    //删除
    @Override
    public void deleteBuild(String buildId) {
        taskBuildDao.deleteBuild(buildId);
    }

    //修改
    @Override
    public void updateBuild(TaskBuild taskBuild) {
        taskBuildDao.updateBuild(BeanMapper.map(taskBuild, TaskBuildDo.class));
    }

    //查询单个
    @Override
    public TaskBuild findOneBuild(String buildId) {
        return BeanMapper.map(taskBuildDao.findOneBuild(buildId), TaskBuild.class);
    }

    //查询所有
    @Override
    public List<TaskBuild> findAllBuild() {
        return BeanMapper.mapList(taskBuildDao.findAllBuild(), TaskBuild.class);
    }

    @Override
    public List<TaskBuild> findAllBuildList(List<String> idList) {
        return BeanMapper.mapList(taskBuildDao.findAllCodeList(idList), TaskBuild.class);
    }
}
