package cd.casic.module.terminal.host.terminal.handler;

import cd.casic.module.terminal.common.BooleanBit;
import cd.casic.module.terminal.common.OperatorLogs;
import cd.casic.module.terminal.define.operator.TerminalOperatorType;
import cd.casic.module.terminal.host.terminal.enums.OutputTypeEnum;
import cd.casic.module.terminal.host.terminal.model.request.SftpBaseRequest;
import cd.casic.module.terminal.host.terminal.model.response.SftpBaseResponse;
import cd.casic.module.terminal.host.terminal.session.ISftpSession;
import cn.orionsec.kit.lang.utils.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.socket.WebSocketSession;
import java.util.Map;

/**
 * sftp 创建文件
 *
 * @author Jiahang Li
 * @version 1.0.0
 * @since 2024/2/19 11:13
 */
@Slf4j
@Component
public class SftpTouchHandler extends AbstractTerminalHandler<SftpBaseRequest> {

    @Override
    public void handle(WebSocketSession channel, SftpBaseRequest payload) {
        long startTime = System.currentTimeMillis();
        // 获取会话
        String sessionId = payload.getSessionId();
        ISftpSession session = terminalManager.getSession(channel.getId(), sessionId);
        String path = payload.getPath();
        log.info("SftpTouchHandler-handle start sessionId: {}, path: {}", sessionId, path);
        Exception ex = null;
        // 创建文件
        try {
            session.touch(path);
            log.info("SftpTouchHandler-handle success sessionId: {}, path: {}", sessionId, path);
        } catch (Exception e) {
            log.error("SftpTouchHandler-handle error sessionId: {}", sessionId, e);
            ex = e;
        }
        // 返回
        this.send(channel,
                OutputTypeEnum.SFTP_TOUCH,
                SftpBaseResponse.builder()
                        .sessionId(sessionId)
                        .result(BooleanBit.of(ex == null).getValue())
                        .msg(this.getErrorMessage(ex))
                        .build());
        // 保存操作日志
        Map<String, Object> extra = Maps.newMap();
        extra.put(OperatorLogs.PATH, path);
        this.saveOperatorLog(payload, channel,
                extra, TerminalOperatorType.SFTP_TOUCH,
                startTime, ex);
    }

}
